-- Version: 7.1 7.1.0.14

library ieee;
use ieee.std_logic_1164.all;
library fusion;

entity my_TOP is

generic (USE_fixed_Time : integer range 0 to 1 := 0);

    port(SYS_CLK_20MHZ : in std_logic; --input main clock of 20Mhz
    SYS_RESET : in std_logic; --active low reset
     
    DATAVALID : out std_logic; 
    INIT_POWER_UP : in std_logic;
 	INIT_DONE_OUTPUT : out std_logic; 
    
    ASSC_CHLATD, ASSC_CHSAT, ASSC_WAIT, ASSC_DONE : out std_logic; 
    
    VAREF : inout std_logic := 'Z'; 
    
    PwrUP, --switch to power up the load supply
    PDOWN  --switch to shut down the load supply
    : in std_logic;
    
    AVN12P0V,    --     -12v supply to analog voltage input
    AV12P0V,     --     12v supply to analog voltage input
    AV5P0V,     --      5.0v supply to analog voltage input
    AV3P3V,     --      3.3v supply to analog voltage input
    ACN12P0V,    --     Current on -12v supply to analog current input
    AC12P0V,     --     Current on 12v supply to analog current input
    AVN12P0V_LOAD, --   -12v load supply to analog voltage input
    AV12P0V_LOAD,  --   12v load supply to analog voltage input
    AV5P0V_LOAD,  --    5.0v load supply to analog voltage input
    AV3P3V_LOAD   --    3.3v load supply to analog voltage input
    : in std_logic; 
    
    ALL_SUPPLY_ON : out std_logic; --Flag used to indiacte all supply are on 
    ALL_LOAD_ON : out std_logic;   --Flag used to indiacte all load supply are on 

    AVN12P0V_ON, --input -12v supply to analog quad
    AV12P0V_ON,  --input 12v supply to analog quad
    AV5P0V_ON,  --input 5.0v supply to analog quad
    AV3P3V_ON : out std_logic); --input 3.3v supply to analog quad

end my_TOP;

architecture DEF_ARCH of my_TOP is 

  -- Analog Block--
  component voltage_n120_120_50_33

    port(SYS_CLK, SYS_RESET : in std_logic; VAREF : inout
         std_logic := 'Z'; DATAVALID : out std_logic; AVn12p0v, 
        AV12p0v, AV5p0v, AVn12p0v_load, AV5p0v_load, ACn12p0v, 
        AC12p0v, AV3p3v, AV12p0v_load, AV3p3v_load : in std_logic; 
        AVn12p0v_ON : out std_logic; AVn12p0v_ENABLE : in
         std_logic; AV12p0v_ON : out std_logic; AV12p0v_ENABLE : 
        in std_logic; AV5p0v_ON : out std_logic; AV5p0v_ENABLE : 
        in std_logic; AV3p3v_ON : out std_logic; AV3p3v_ENABLE : 
        in std_logic; AVn12p0v_UNDERn10p8V, ACn12p0v_over1p5a, 
        AV3p3v_OVER3p17V, AV12p0v_OVER11p4V, AC12p0v_over2p0a, 
        AV12p0v_load_over_11p4v, AV12p0v_load_under_0p8v, 
        AV5p0v_OVER4p75V, AV3p3v_load_over_3p17v, 
        AV3p3v_load_under_0p8v, AVn12p0v_load_over_n0p8v, 
        AVn12p0v_load_under_n10p8v, AV5p0v_load_over_4p75v, 
        AV5p0v_load_under_0p8v, ASSC_DONE, ASSC_WAIT, ASSC_CHSAT, 
        ASSC_CHLATD : out std_logic; INIT_ADDR : 
        in std_logic_vector(8 downto 0); INIT_DATA : 
        in std_logic_vector(8 downto 0); INIT_ACM_WEN, 
        INIT_ASSC_WEN, INIT_EV_WEN, INIT_TR_WEN, INIT_DONE : in
         std_logic);
  end component;

  --Flash Memory Block--
    component nvm_init
      port(INIT_CLK, SYS_RESET, INIT_POWER_UP : in std_logic := 'U'; 
          INIT_DONE : out std_logic; INIT_DATA : 
          out std_logic_vector(8 downto 0); INIT_ADDR : 
          out std_logic_vector(8 downto 0); INIT_ACM_WEN, 
          INIT_ASSC_WEN, INIT_EV_WEN, INIT_TR_WEN : out std_logic);
  
   end component;

  --Sequencing Control State Machine--
    component voltage_seq_control
      generic (USE_fixed_Time : integer range 0 to 1 := 1);
        port(SYS_CLK, SYS_RESET : in std_logic := 'U'; AVN12P0V_ENABLE, 
            AV12P0V_ENABLE, AV5P0V_ENABLE, AV3P3V_ENABLE, 
            ALL_SUPPLY_ON, ALL_LOAD_ON : out std_logic; PwrUP, PDOWN, 
            AVn12p0v_UNDERn10p8V, ACn12p0v_over1p5a, 
            AV12p0v_OVER11p4V, AC12p0v_over2p0a,
            AV5p0v_OVER4p75V, AV3p3v_OVER3p17V,
            AVn12p0v_load_under_n10p8v, AVn12p0v_load_over_n0p8v, 
            AV12p0v_load_over_11p4v, AV12p0v_load_under_0p8v, 
            AV5p0v_load_over_4p75v, AV5p0v_load_under_0p8v,  
            AV3p3v_load_over_3p17v, AV3p3v_load_under_0p8v 
            : in std_logic := 'U');
    end component;  



  component INV
        port(A : in std_logic := 'U'; Y : out std_logic);
  end component;

  component MX2
    port(A, B, S : in std_logic := 'U'; Y : out std_logic);
  end component;

  component DFN1C0
    port(D, CLK, CLR : in std_logic := 'U'; Q : out std_logic);
  end component;



    signal FF1_IN: std_logic;
     
    --Signals between Analog and Flash Memory Block--
    signal INIT_ADDR_to_INIT_ADDR : std_logic_vector(8 downto 0);
    signal INIT_DATA_to_INIT_DATA : std_logic_vector(8 downto 0);
    signal INIT_DONE_net : std_logic;
    signal INIT_ACM_WEN, INIT_ASSC_WEN, INIT_ACM_RTC_WEN, INIT_EV_WEN, INIT_TR_WEN : std_logic;
    
    --Clock Signals--
    signal MAIN_CLK, SYS_CLK_10MHZ : std_logic;

    --Gate Driver Enable Signals--
    signal AVn12p0v_ENABLE_int, AV12p0v_ENABLE_int, AV5p0v_ENABLE_int, AV3p3v_ENABLE_int : std_logic; 

    --Threshold Flags Signals for Supply Side--
    signal 	AV12p0v_OVER11p4V_int, AC12p0v_over2p0a_int,
	        AVn12p0v_UNDERn10p8V_int, ACn12p0v_over1p5a_int, 
       	    AV5p0v_OVER4p75V_int, AV3p3v_OVER3p17V_int : std_logic;  

    --Threshold Flags Signals for Load Side--
    signal  AV12p0v_load_over_11p4v_int, AV12p0v_load_under_0p8v_int,
            AVn12p0v_load_over_n0p8v_int, AVn12p0v_load_under_n10p8v_int,
	        AV5p0v_load_over_4p75v_int, AV5p0v_load_under_0p8v_int,
	        AV3p3v_load_over_3p17v_int, AV3p3v_load_under_0p8v_int : std_logic; 
         


begin 

    INIT_DONE_OUTPUT <= INIT_DONE_net;


--- Analog Block
    
    ADC_BLOCK : voltage_n120_120_50_33
      port map(
      	SYS_CLK => MAIN_CLK, 
      	SYS_RESET => SYS_RESET, 
      	VAREF     => VAREF, 
      	DATAVALID => DATAVALID, 
      	
      	-- Voltage Inputs for Supply Side--	
      	AVn12p0v => AVN12P0V,
        ACn12p0v =>ACN12P0V,
        
        AV12p0v => AV12P0V, 
        AC12p0v =>AC12P0V,
        
        AV5p0v =>AV5P0V,
        
        AV3p3v =>AV3P3V,
        
        -- Voltage Inputs for Load Side--
        AVn12p0v_load =>AVN12P0V_LOAD,
        AV12p0v_load =>AV12P0V_LOAD,
        AV5p0v_load =>AV5P0V_LOAD,
        AV3p3v_load =>AV3P3V_LOAD,
        
        --Gate Driver Enable and Output Signals--
        AVn12p0v_ENABLE =>AVn12p0v_ENABLE_int,
        AVn12p0v_ON =>AVn12p0v_ON,
        
        AV12p0v_ENABLE =>AV12p0v_ENABLE_int,
        AV12p0v_ON =>AV12p0v_ON,
        
        AV5p0v_ENABLE =>AV5p0v_ENABLE_int,
        AV5p0v_ON =>AV5p0v_ON,
        
        AV3p3v_ENABLE =>AV3p3v_ENABLE_int,
        AV3p3v_ON =>AV3p3v_ON,
        
        --Threshold Flags for Supply Side--
        AVn12p0v_UNDERn10p8V =>AVn12p0v_UNDERn10p8V_int,
        ACn12p0v_over1p5a =>ACn12p0v_over1p5a_int, 
        
        AV12p0v_OVER11p4V =>AV12p0v_OVER11p4V_int, 
        AC12p0v_over2p0a =>AC12p0v_over2p0a_int,
        
        AV5p0v_OVER4p75V =>AV5p0v_OVER4p75V_int, 
        
        AV3p3v_OVER3p17V =>AV3p3v_OVER3p17V_int,
        
        --Threshold Flags for Load Side--
        AVn12p0v_load_over_n0p8v =>AVn12p0v_load_over_n0p8v_int, 
        AVn12p0v_load_under_n10p8v =>AVn12p0v_load_under_n10p8v_int, 
        
        AV12p0v_load_over_11p4v =>AV12p0v_load_over_11p4v_int, 
        AV12p0v_load_under_0p8v =>AV12p0v_load_under_0p8v_int, 
        
        AV5p0v_load_over_4p75v =>AV5p0v_load_over_4p75v_int, 
        AV5p0v_load_under_0p8v =>AV5p0v_load_under_0p8v_int,	
        
        AV3p3v_load_over_3p17v =>AV3p3v_load_over_3p17v_int,
        AV3p3v_load_under_0p8v =>AV3p3v_load_under_0p8v_int, 
        
        --ASSC Signals--
        ASSC_DONE => ASSC_DONE, 
        ASSC_WAIT => ASSC_WAIT, 
        ASSC_CHSAT => ASSC_CHSAT, 
        ASSC_CHLATD => ASSC_CHLATD, 
        
        --Signals Connected to Flash Memory Block--
        INIT_DATA =>	INIT_DATA_to_INIT_DATA,
	    INIT_ADDR		=>	INIT_ADDR_to_INIT_ADDR,
	    INIT_DONE		=>	INIT_DONE_net,
	    INIT_ACM_WEN	=>	INIT_ACM_WEN,
	    INIT_ASSC_WEN	=>	INIT_ASSC_WEN,
	    INIT_EV_WEN		=>	INIT_EV_WEN,
	    INIT_TR_WEN		=>	INIT_TR_WEN
        
        );




 --- Flash Memory block used to store the analog configuration data
    FlashMemory_BLOCK : nvm_init
      port map(
      	INIT_CLK => MAIN_CLK, 
      	SYS_RESET => SYS_RESET, 
        INIT_POWER_UP => INIT_POWER_UP, 
        
        --Signals Connected to Analog Block--
        INIT_DONE => INIT_DONE_net, 
        INIT_DATA		=>	INIT_DATA_to_INIT_DATA,
	    INIT_ADDR		=>	INIT_ADDR_to_INIT_ADDR,
	    INIT_ACM_WEN	=>	INIT_ACM_WEN,
	    INIT_ASSC_WEN	=>	INIT_ASSC_WEN,
	    INIT_EV_WEN		=>	INIT_EV_WEN,
	    INIT_TR_WEN		=>	INIT_TR_WEN
               );
    
  
  
 --- main voltage sequence controller block
    MY_VOLTAGE_SEQ : voltage_seq_control

       generic map ( USE_fixed_Time => USE_fixed_Time)

      port map(
      	SYS_CLK => SYS_CLK_20MHZ, 
      	SYS_RESET => SYS_RESET, 
        
        AVN12P0V_ENABLE => AVn12p0v_ENABLE_int, 
        AV12P0V_ENABLE => AV12p0v_ENABLE_int, 
        AV5P0V_ENABLE => AV5p0v_ENABLE_int, 
        AV3P3V_ENABLE => AV3p3v_ENABLE_int, 
        
        ALL_SUPPLY_ON => ALL_SUPPLY_ON, 
        ALL_LOAD_ON => ALL_LOAD_ON, 
        PwrUP => PwrUP,
        PDOWN => PDOWN, 
        
        --Threshold Flags for Supply Side Control--
        AVn12p0v_UNDERn10p8V => AVn12p0v_UNDERn10p8V_int, 
        ACn12p0v_over1p5a => OPEN, 
        
        AV12p0v_OVER11p4V => AV12p0v_OVER11p4V_int, 
        AC12p0v_over2p0a => OPEN, 
        
        AV5p0v_OVER4p75V =>AV5p0v_OVER4p75V_int,
        
        AV3p3v_OVER3p17V =>AV3p3v_OVER3p17V_int,
        
        
        --Threshold Flags for Load Side Control--
        AVn12p0v_load_over_n0p8v =>AVn12p0v_load_over_n0p8v_int, 
	    AVn12p0v_load_under_n10p8v =>AVn12p0v_load_under_n10p8v_int, 
	        
	    AV12p0v_load_over_11p4v =>AV12p0v_load_over_11p4v_int, 
	    AV12p0v_load_under_0p8v =>AV12p0v_load_under_0p8v_int, 
	        
	    AV5p0v_load_over_4p75v =>AV5p0v_load_over_4p75v_int, 
	    AV5p0v_load_under_0p8v =>AV5p0v_load_under_0p8v_int,	
	        
	    AV3p3v_load_over_3p17v =>AV3p3v_load_over_3p17v_int,
        AV3p3v_load_under_0p8v =>AV3p3v_load_under_0p8v_int 
     
        ); 
      
          
    INV1 : INV
      port map(A => SYS_CLK_10MHZ, Y => FF1_IN);



    
    MY_MUX : MX2
      port map(A => SYS_CLK_20MHZ, B => SYS_CLK_10MHZ, S => 
        INIT_DONE_net, Y => MAIN_CLK);
    
    FF1 : DFN1C0
      port map(D => FF1_IN, CLK => SYS_CLK_20MHZ, CLR => 
        SYS_RESET, Q => SYS_CLK_10MHZ);
    

end DEF_ARCH; 
