-- Version: 7.1 7.1.0.14

library ieee;
use ieee.std_logic_1164.all;
library fusion;

entity TOP is

    port(SYS_CLK_20MHZ : in std_logic; AVN5P0V_ON, DATAVALID : 
        out std_logic; INIT_POWER_UP : in std_logic; 
        INIT_DONE_OUTPUT : out std_logic; SYS_RESET : in
         std_logic; ASSC_CHLATD, ASSC_CHSAT, ASSC_WAIT, ASSC_DONE : 
        out std_logic; VAREF : inout std_logic := 'Z'; PDOWN, 
        AVN5P0V, AV5P0V, AV1P5V, AVN5P0V_LOAD, AV5P0V_LOAD, 
        AV1P5V_LOAD, ACN5P0V, AC5P0V, AV3P3V, AV3P3V_LOAD : in
         std_logic; AV5P0V_ON, AV3P3V_ON, AV1P5V_ON : out
         std_logic);

end TOP;

architecture DEF_ARCH of TOP is 

  component nvm_init
    port(INIT_CLK, SYS_RESET, INIT_POWER_UP : in std_logic := 'U'; 
        INIT_DONE : out std_logic; INIT_DATA : 
        out std_logic_vector(8 downto 0); INIT_ADDR : 
        out std_logic_vector(8 downto 0); INIT_ACM_WEN, 
        INIT_ASSC_WEN, INIT_EV_WEN, INIT_TR_WEN : out std_logic);

          end component;

  component voltage_seq_control
    port(SYS_CLK, SYS_RESET : in std_logic := 'U'; AVN5P0V_ENABLE, 
        AV5P0V_ENABLE, AV3P3V_ENABLE, AV1P5V_ENABLE, 
        ALL_SUPPLY_ON, ALL_LOAD_ON : out std_logic; PDOWN, 
        AVN5P0V_OVERN4P5V, ACN5P0V_OVER1P5A, 
        AVN5P0_LOAD_OVER_N3P7V, AVN5P0_LOAD_UNDER_N0P8V, 
        AV5P0V_OVER4P5V, AC5P0V_AC5P0V_OVER2P0A, 
        AV5P0_LOAD_OVER_3P7V, AV5P0_LOAD_UNDER_0P8V, 
        AV3P3V_OVER3P0V, AV3P3_LOAD_OVER_2P8V, 
        AV3P3_LOAD_UNDER_0P8V, AV1P5V_OVER1P425V, 
        AV1P5_LOAD_OVER_0P975V, AV1P5_LOAD_UNDER_0P5V : in
         std_logic := 'U');
  end component;

  component INV
    port(A : in std_logic := 'U'; Y : out std_logic);
  end component;

  component voltage_n50_50_33_15
    port(SYS_CLK, SYS_RESET : in std_logic := 'U'; VAREF : inout
         std_logic; DATAVALID : out std_logic; AVN5P0V, AV5P0V, 
        AV1P5V, AVN5P0V_LOAD, AV5P0V_LOAD, AV1P5V_LOAD, ACN5P0V, 
        AC5P0V, AV3P3V, AV3P3V_LOAD : in std_logic := 'U'; 
        AVN5P0V_ON : out std_logic; AVN5P0V_ENABLE : in
         std_logic := 'U'; AV5P0V_ON : out std_logic; 
        AV5P0V_ENABLE : in std_logic := 'U'; AV3P3V_ON : out
         std_logic; AV3P3V_ENABLE : in std_logic := 'U'; 
        AV1P5V_ON : out std_logic; AV1P5V_ENABLE : in
         std_logic := 'U'; AVN5P0V_AVN5P0V_OVERN4P5V, 
        ACN5P0V_ACN5P0V_OVER1P5A, AV3P3V_AV3P3V_OVER3P0V, 
        AV5P0V_AV5P0V_OVER4P5V, AC5P0V_AC5P0V_OVER2P0A, 
        AV3P3V_LOAD_AV3P3_LOAD_OVER_2P8V, 
        AV3P3V_LOAD_AV3P3_LOAD_UNDER_0P8V, 
        AV1P5V_AV1P5V_OVER1P425V, 
        AVN5P0V_LOAD_AVN5P0_LOAD_OVER_N3P7V, 
        AVN5P0V_LOAD_AVN5P0_LOAD_UNDER_N0P8V, 
        AV5P0V_LOAD_AV5P0_LOAD_OVER_3P7V, 
        AV5P0V_LOAD_AV5P0_LOAD_UNDER_0P8V, 
        AV1P5V_LOAD_AV1P5_LOAD_OVER_0P975V, 
        AV1P5V_LOAD_AV1P5_LOAD_UNDER_0P5, ASSC_DONE, ASSC_WAIT, 
        ASSC_CHSAT, ASSC_CHLATD : out std_logic; INIT_ADDR : 
        in std_logic_vector(8 downto 0) := (others => 'U'); 
        INIT_DATA : 
        in std_logic_vector(8 downto 0) := (others => 'U'); 
        INIT_ACM_WEN, INIT_ASSC_WEN, INIT_EV_WEN, INIT_TR_WEN, 
        INIT_DONE : in std_logic := 'U');
  end component;

  component MX2
    port(A, B, S : in std_logic := 'U'; Y : out std_logic);
  end component;

  component DFN1C0
    port(D, CLK, CLR : in std_logic := 'U'; Q : out std_logic);
  end component;

    signal AV1P5V_EN_INT, AV3P3V_EN_INT, AV5P0V_EN_INT, 
        AVN5P0V_EN_INT, FF1_IN, INIT_ACM_WEN_INT : std_logic;
    signal INIT_ADDR_INT : std_logic_vector(8 downto 0);
    signal \INIT_ADDR_INT\, INIT_ADDR_INT_net_1, 
        INIT_ADDR_INT_net_2, INIT_ADDR_INT_net_3, 
        INIT_ADDR_INT_net_4, INIT_ADDR_INT_net_5, 
        INIT_ADDR_INT_net_6, INIT_ADDR_INT_net_7, 
        INIT_ASSC_WEN_INT : std_logic;
    signal INIT_DATA_INT : std_logic_vector(8 downto 0);
    signal \INIT_DATA_INT\, INIT_DATA_INT_net_1, 
        INIT_DATA_INT_net_2, INIT_DATA_INT_net_3, 
        INIT_DATA_INT_net_4, INIT_DATA_INT_net_5, 
        INIT_DATA_INT_net_6, INIT_DATA_INT_net_7, 
        \INIT_DONE_OUTPUT\, INIT_EV_WEN_INT, INIT_TR_WEN_INT, 
        MAIN_CLK, SYS_CLK_10MHZ : std_logic;

begin 

    INIT_DONE_OUTPUT <= \INIT_DONE_OUTPUT\;

    NVM_BLK : nvm_init
      port map(INIT_CLK => MAIN_CLK, SYS_RESET => SYS_RESET, 
        INIT_POWER_UP => INIT_POWER_UP, INIT_DONE => 
        \INIT_DONE_OUTPUT\, INIT_DATA(8) => INIT_DATA_INT(8), 
        INIT_DATA(7) => \INIT_DATA_INT\, INIT_DATA(6) => 
        INIT_DATA_INT_net_1, INIT_DATA(5) => INIT_DATA_INT_net_2, 
        INIT_DATA(4) => INIT_DATA_INT_net_3, INIT_DATA(3) => 
        INIT_DATA_INT_net_4, INIT_DATA(2) => INIT_DATA_INT_net_5, 
        INIT_DATA(1) => INIT_DATA_INT_net_6, INIT_DATA(0) => 
        INIT_DATA_INT_net_7, INIT_ADDR(8) => INIT_ADDR_INT(8), 
        INIT_ADDR(7) => \INIT_ADDR_INT\, INIT_ADDR(6) => 
        INIT_ADDR_INT_net_1, INIT_ADDR(5) => INIT_ADDR_INT_net_2, 
        INIT_ADDR(4) => INIT_ADDR_INT_net_3, INIT_ADDR(3) => 
        INIT_ADDR_INT_net_4, INIT_ADDR(2) => INIT_ADDR_INT_net_5, 
        INIT_ADDR(1) => INIT_ADDR_INT_net_6, INIT_ADDR(0) => 
        INIT_ADDR_INT_net_7, INIT_ACM_WEN => INIT_ACM_WEN_INT, 
        INIT_ASSC_WEN => INIT_ASSC_WEN_INT, INIT_EV_WEN => 
        INIT_EV_WEN_INT, INIT_TR_WEN => INIT_TR_WEN_INT);
    
    MY_VOLTAGE_SEQ : voltage_seq_control
      port map(SYS_CLK => SYS_CLK_20MHZ, SYS_RESET => SYS_RESET, 
        AVN5P0V_ENABLE => AVN5P0V_EN_INT, AV5P0V_ENABLE => 
        AV5P0V_EN_INT, AV3P3V_ENABLE => AV3P3V_EN_INT, 
        AV1P5V_ENABLE => AV1P5V_EN_INT, ALL_SUPPLY_ON => OPEN, 
        ALL_LOAD_ON => OPEN, PDOWN => PDOWN, AVN5P0V_OVERN4P5V
         => OPEN, ACN5P0V_OVER1P5A => OPEN, 
        AVN5P0_LOAD_OVER_N3P7V => OPEN, AVN5P0_LOAD_UNDER_N0P8V
         => OPEN, AV5P0V_OVER4P5V => OPEN, AC5P0V_AC5P0V_OVER2P0A
         => OPEN, AV5P0_LOAD_OVER_3P7V => OPEN, 
        AV5P0_LOAD_UNDER_0P8V => OPEN, AV3P3V_OVER3P0V => OPEN, 
        AV3P3_LOAD_OVER_2P8V => OPEN, AV3P3_LOAD_UNDER_0P8V => 
        OPEN, AV1P5V_OVER1P425V => OPEN, AV1P5_LOAD_OVER_0P975V
         => OPEN, AV1P5_LOAD_UNDER_0P5V => OPEN);
    
    INV1 : INV
      port map(A => SYS_CLK_10MHZ, Y => FF1_IN);
    
    ADC_BLOCK : voltage_n50_50_33_15
      port map(SYS_CLK => MAIN_CLK, SYS_RESET => SYS_RESET, VAREF
         => VAREF, DATAVALID => DATAVALID, AVN5P0V => AVN5P0V, 
        AV5P0V => AV5P0V, AV1P5V => AV1P5V, AVN5P0V_LOAD => 
        AVN5P0V_LOAD, AV5P0V_LOAD => AV5P0V_LOAD, AV1P5V_LOAD => 
        AV1P5V_LOAD, ACN5P0V => ACN5P0V, AC5P0V => AC5P0V, AV3P3V
         => AV3P3V, AV3P3V_LOAD => AV3P3V_LOAD, AVN5P0V_ON => 
        AVN5P0V_ON, AVN5P0V_ENABLE => AVN5P0V_EN_INT, AV5P0V_ON
         => AV5P0V_ON, AV5P0V_ENABLE => AV5P0V_EN_INT, AV3P3V_ON
         => AV3P3V_ON, AV3P3V_ENABLE => AV3P3V_EN_INT, AV1P5V_ON
         => AV1P5V_ON, AV1P5V_ENABLE => AV1P5V_EN_INT, 
        AVN5P0V_AVN5P0V_OVERN4P5V => OPEN, 
        ACN5P0V_ACN5P0V_OVER1P5A => OPEN, AV3P3V_AV3P3V_OVER3P0V
         => OPEN, AV5P0V_AV5P0V_OVER4P5V => OPEN, 
        AC5P0V_AC5P0V_OVER2P0A => OPEN, 
        AV3P3V_LOAD_AV3P3_LOAD_OVER_2P8V => OPEN, 
        AV3P3V_LOAD_AV3P3_LOAD_UNDER_0P8V => OPEN, 
        AV1P5V_AV1P5V_OVER1P425V => OPEN, 
        AVN5P0V_LOAD_AVN5P0_LOAD_OVER_N3P7V => OPEN, 
        AVN5P0V_LOAD_AVN5P0_LOAD_UNDER_N0P8V => OPEN, 
        AV5P0V_LOAD_AV5P0_LOAD_OVER_3P7V => OPEN, 
        AV5P0V_LOAD_AV5P0_LOAD_UNDER_0P8V => OPEN, 
        AV1P5V_LOAD_AV1P5_LOAD_OVER_0P975V => OPEN, 
        AV1P5V_LOAD_AV1P5_LOAD_UNDER_0P5 => OPEN, ASSC_DONE => 
        ASSC_DONE, ASSC_WAIT => ASSC_WAIT, ASSC_CHSAT => 
        ASSC_CHSAT, ASSC_CHLATD => ASSC_CHLATD, INIT_ADDR(8) => 
        INIT_ADDR_INT(8), INIT_ADDR(7) => \INIT_ADDR_INT\, 
        INIT_ADDR(6) => INIT_ADDR_INT_net_1, INIT_ADDR(5) => 
        INIT_ADDR_INT_net_2, INIT_ADDR(4) => INIT_ADDR_INT_net_3, 
        INIT_ADDR(3) => INIT_ADDR_INT_net_4, INIT_ADDR(2) => 
        INIT_ADDR_INT_net_5, INIT_ADDR(1) => INIT_ADDR_INT_net_6, 
        INIT_ADDR(0) => INIT_ADDR_INT_net_7, INIT_DATA(8) => 
        INIT_DATA_INT(8), INIT_DATA(7) => \INIT_DATA_INT\, 
        INIT_DATA(6) => INIT_DATA_INT_net_1, INIT_DATA(5) => 
        INIT_DATA_INT_net_2, INIT_DATA(4) => INIT_DATA_INT_net_3, 
        INIT_DATA(3) => INIT_DATA_INT_net_4, INIT_DATA(2) => 
        INIT_DATA_INT_net_5, INIT_DATA(1) => INIT_DATA_INT_net_6, 
        INIT_DATA(0) => INIT_DATA_INT_net_7, INIT_ACM_WEN => 
        INIT_ACM_WEN_INT, INIT_ASSC_WEN => INIT_ASSC_WEN_INT, 
        INIT_EV_WEN => INIT_EV_WEN_INT, INIT_TR_WEN => 
        INIT_TR_WEN_INT, INIT_DONE => \INIT_DONE_OUTPUT\);
    
    MY_MUX : MX2
      port map(A => SYS_CLK_20MHZ, B => SYS_CLK_10MHZ, S => 
        \INIT_DONE_OUTPUT\, Y => MAIN_CLK);
    
    FF1 : DFN1C0
      port map(D => FF1_IN, CLK => SYS_CLK_20MHZ, CLR => 
        SYS_RESET, Q => SYS_CLK_10MHZ);
    

end DEF_ARCH; 
